@@ -6,7 +6,7 @@ import enum
 import json
 from copy import deepcopy
 from collections import OrderedDict, deque, defaultdict
-from inspect import Signature, Parameter, signature
+from inspect import Signature, Parameter, signature, currentframe
 import sys
 import typing
 import hashlib
@@ -316,7 +316,8 @@ class Field(UniqueMixin, metaclass=_FieldMeta):
         if immutable is not None:
             self._immutable = immutable
         if default:
-            self._try_default_value(default)
+            default_val = default() if callable(default) else default
+            self._try_default_value(default_val)
 
     def _try_default_value(self, default):
         try:
@@ -336,7 +337,8 @@ class Field(UniqueMixin, metaclass=_FieldMeta):
             return field_by_name[name]
 
         if instance is not None and self._name not in instance.__dict__:
-            return self._default
+            default_value = self._default() if callable(self._default) else self._default
+            return default_value
         res = (
             instance.__dict__[self._name]
             if instance is not None
@@ -433,6 +435,17 @@ def _get_all_fields_by_name(cls):
     return all_fields_by_name
 
 
+def _get_all_values_of_attribute(cls, attr_name: str):
+    all_classes = reversed([c for c in cls.mro() if isinstance(c, StructMeta)])
+    all_values = []
+    for the_class in all_classes:
+        if issubclass(the_class, Structure):
+            attr = getattr(the_class, attr_name, None)
+            if attr is not None:
+                all_values.append(attr)
+    return all_values
+
+
 def _instantiate_fields_if_needed(cls_dict: dict, defaults: dict):
     for key, val in cls_dict.items():
         if (
@@ -457,7 +470,8 @@ def _apply_default_and_update_required_not_to_include_fields_with_defaults(
         if field_name in defaults and not getattr(
             cls_dict[field_name], "_default", None
         ):
-            cls_dict[field_name]._try_default_value(defaults[field_name])
+            default_value = defaults[field_name]() if callable(defaults[field_name]) else defaults[field_name]
+            cls_dict[field_name]._try_default_value(default_value)
             cls_dict[field_name]._default = defaults[field_name]
         if getattr(cls_dict[field_name], "_default", None) is not None:
             if field_name in required_fields:
@@ -479,7 +493,7 @@ class StructMeta(type):
 
     def __new__(cls, name, bases, cls_dict):
         bases_params, bases_required = get_base_info(bases)
-        add_annotations_to_class_dict(cls_dict)
+        add_annotations_to_class_dict(cls_dict, previous_frame=currentframe().f_back)
         defaults = cls_dict[DEFAULTS]
         _instantiate_fields_if_needed(cls_dict=cls_dict, defaults=defaults)
 
@@ -597,12 +611,14 @@ def get_typing_lib_info(v):
     return mapped_type()
 
 
-def add_annotations_to_class_dict(cls_dict):
+def add_annotations_to_class_dict(cls_dict, previous_frame):
     annotations = cls_dict.get("__annotations__", {})
     defaults = {}
     optional_fields = set(cls_dict.get(OPTIONAL_FIELDS, []))
     if isinstance(annotations, dict):
         for k, v in annotations.items():
+            if isinstance(v, str):
+                v = eval(v, sys.modules[cls_dict['__module__']].__dict__, previous_frame.f_locals)
             first_arg = getattr(v, "__args__", [0])[0]
             mros = getattr(first_arg, "__mro__", getattr(v, "__mro__", []))
             if not type_is_generic(v) and (
@@ -710,6 +726,14 @@ class Structure(UniqueMixin, metaclass=StructMeta):
                 setattr(self, name, val)
             del bound.arguments["kwargs"]
 
+        field_by_name = self.get_all_fields_by_name()
+        defaults_fields = [key for key in field_by_name if getattr(field_by_name[key], "_default", None) is
+                           not None and key not in bound.arguments]
+        for field_name in defaults_fields:
+            default = getattr(field_by_name[field_name], "_default")
+            default_value = default() if callable(default) else default
+            setattr(self, field_name, default_value)
+
         if Structure.failing_fast():
             for name, val in bound.arguments.items():
                 setattr(self, name, val)
@@ -862,6 +886,10 @@ class Structure(UniqueMixin, metaclass=StructMeta):
     def get_all_fields_by_name(cls):
         return _get_all_fields_by_name(cls)
 
+    @classmethod
+    def get_aggregated_serialization_mapper(cls):
+        return _get_all_values_of_attribute(cls, MAPPER)
+
     def _is_wrapper(self):
         field_by_name = _get_all_fields_by_name(self.__class__)
         field_names = list(field_by_name.keys())
@@ -940,6 +968,102 @@ class Structure(UniqueMixin, metaclass=StructMeta):
 
         raise TypeError(f"cls must be subclass of {self.__class__.__name__}")
 
+    def to_other_class(
+            self, target_class, *, ignore_props=None, **kw
+    ) -> T:
+        """
+        Shallow copy of the fields in the structure and instantiate an instance of the given target_class
+        Arguments:
+            target_class:
+                The target class of the new object to be instantiated from this structure.
+                This does not need to be a class:`Structure`.
+
+                Example:
+
+                .. code-block:: python
+                    class Person:
+                        def __init__(self ,* ,name, age):
+                            ...
+
+                    class Foo(Structure):
+                        id = Integer
+                        name = String
+
+                    person = Foo(id=1, name="john").to_other_class(Person, ignore_props=["id"], age=40)
+                    assert person.age == 40
+                    assert.person.name == "john"
+
+            ignore_props(list[str]): optional
+                a list of field names to be ignored (not copied).
+
+            kw: optional
+                any overrides of attributes. For example: "age="40" in the code snippet above
+
+        Returns:
+            A new instance of the provided target_class with all the attributes of the current structure,
+            except the ones state in the ignore_props parameters, and also the attributes overrides given in
+            the keyword arguments.
+            :param ignore_props:
+        """
+        ignore_props = ignore_props if ignore_props else []
+        args_from_structure = {
+            k: getattr(self, k, None)
+            for k in self.get_all_fields_by_name()
+            if k not in ignore_props
+        }
+        kwargs = {**args_from_structure, **kw}
+        return target_class(**kwargs)
+
+    @classmethod
+    def from_other_class(
+            cls, source_object, *, ignore_props=None, **kw
+    ):
+        """
+        Return a new instance of the current :class:`Structure`, with the attributes of the source_object.
+        The optional parameters allow to ignore/override attributes.
+        For example:
+
+        .. code-block:: python
+                    class PersonModel:
+                        def __init__(self ,* ,first_name, age):
+                            ...
+
+                    class Person(Structure):
+                        id = Integer
+                        name = String
+                        age = Integer
+
+                    person_model = PersonModel(first_name="john", age=40)
+                    person = Person.from_other_class(
+                        person_model,
+                        id=123,
+                        name=person_model.first_name
+                    )
+                    assert person == Person(name="john", id=123, age=40)
+
+        Arguments:
+            source_object:
+                The source object to be copied from. Can be of any type.
+
+            ignore_props(list[str]): optional
+                The field names to ignore (not copy)
+
+            kw: optional
+                explicit overrides/additional field mapping. In the snippet above we
+                set the "id" and "name" fields directly.
+
+        Returns:
+            The new instance of the current structure type, with the fields set.
+        """
+        ignore_props = ignore_props if ignore_props else []
+        args_from_model = {
+            k: getattr(source_object, k, None)
+            for k in cls.get_all_fields_by_name()
+            if k not in ignore_props
+        }
+        kwargs = {**args_from_model, **kw}
+        return cls(**kwargs)
+
     @staticmethod
     def set_fail_fast(fast_fail: bool):
         Structure._fail_fast = fast_fail
